
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * Windows version 4                              *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Display Windows version.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_b64BitsOS                     Boolean    Internal       Indicate program is running on 64 bits operating system.
rem         g_strRootPath                   String     Internal       
rem         g_strPath                       String     Internal       
rem         g_strWindowsProductId           String     Output         Windows product ID
rem         g_strWindowsProductName         String     Output         Windows product name
rem         g_strWindowsBuildLab            String     Output         Windows build lab
rem         g_strWindowsBuildLabEx          String     Output         Windows build lab ex
rem         g_strWindowsCSDVersion          String     Output         Windows CSD version
rem         g_strWindowsCSDBuildNumber      String     Output         Windows CSD build number
rem         g_uWinVersion                   U. int     Output         <See below>
rem         g_strWinVersion                 String     Output         <See below>
rem         g_bIsServer                     Boolean    Output         [0..1] Indicate server version of Windows
rem 
rem: Sources :
rem         http://stackoverflow.com/questions/953416/find-out-the-language-windows-was-installed-as
rem         http://www.windowsitpro.com/article/configuration/where-in-the-registry-is-the-language-setting-for-each-user-stored-
rem         http://msdn.microsoft.com/en-us/library/ms533052(v=vs.85).aspx
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log
set g_strTempFolder=!g_strBatchPath!\..\temp

set g_strCommandIs64Bits4FullPath=!g_strCmdLineToolsFolder!\Is64Bits4.exe
set g_strCommandCheckRange4FullPath=!g_strCmdLineToolsFolder!\CheckRange4.exe
set g_strCommandRegRead4FullPath=!g_strCmdLineToolsFolder!\RegRead4.exe
set g_strCommandWinVersion4FullPath=!g_strCmdLineToolsFolder!\WinVersion4.exe

set g_strRootPath=HKLM
set g_strPath=SOFTWARE\Microsoft\Windows NT\CurrentVersion


rem Display current directory
echo - Batch directory : 
echo !g_strBatchPath!
echo.
rem Display current directory
echo - Current directory : 
echo !g_strCurrentDirectory!
echo.
rem Display CmdLineTools directory
echo - CmdLineTools directory : 
echo !g_strCmdLineToolsFolder!
echo.

rem Call command and store result
"!g_strCommandIs64Bits4FullPath!" -q
if %ERRORLEVEL%==1 (
    set g_b64BitsOS=1
) else if %ERRORLEVEL%==0 (
    set g_b64BitsOS=0
) else (
    set g_b64BitsOS=-1
)

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

REM ----------------------------------------
REM
REM Get Windows generic informations
REM
REM ----------------------------------------
echo Read Windows language in Registry

if %g_b64BitsOS%==1 (
    "!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "ProductId" -x64 > "!g_strInternalOutputFullFilename!"
) else (
    "!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "ProductId" -x86 > "!g_strInternalOutputFullFilename!"
)
set /p g_strWindowsProductId= < "!g_strInternalOutputFullFilename!"

"!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "ProductName" -x86 > "!g_strInternalOutputFullFilename!"
set /p g_strWindowsProductName= < "!g_strInternalOutputFullFilename!"

"!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "BuildLab" -x86 > "!g_strInternalOutputFullFilename!"
set /p g_strWindowsBuildLab= < "!g_strInternalOutputFullFilename!"

"!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "BuildLabEx" -x86 > "!g_strInternalOutputFullFilename!"
set /p g_strWindowsBuildLabEx= < "!g_strInternalOutputFullFilename!"

if %g_b64BitsOS%==1 (
    "!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "CSDVersion" -x64 > "!g_strInternalOutputFullFilename!"
) else (
    "!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "CSDVersion" -x86 > "!g_strInternalOutputFullFilename!"
)
set /p g_strWindowsCSDVersion= < "!g_strInternalOutputFullFilename!"

"!g_strCommandRegRead4FullPath!" -r %g_strRootPath% -p "%g_strPath%" -v "CSDBuildNumber" -x86 > "!g_strInternalOutputFullFilename!"
set /p g_strWindowsCSDBuildNumber= < "!g_strInternalOutputFullFilename!"

rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "ProductId"') do set g_strWindowsProductId=%%a
rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "ProductName"') do set g_strWindowsProductName=%%a
rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "BuildLab"') do set g_strWindowsBuildLab=%%a
rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "BuildLabEx"') do set g_strWindowsBuildLabEx=%%a
rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "CSDVersion"') do set g_strWindowsCSDVersion=%%a
rem for /f "tokens=*" %%a in ('"%strRegReadFullPath%" %g_strRootPath% -p "%g_strPath%" -v "CSDBuildNumber"') do set g_strWindowsCSDBuildNumber=%%a

echo.
echo Windows product Id        : %g_strWindowsProductId%
echo Windows product name      : %g_strWindowsProductName%
echo Windows build lab         : %g_strWindowsBuildLab%
echo Windows build lab ex      : %g_strWindowsBuildLabEx%
echo Windows CSD version       : %g_strWindowsCSDVersion%
echo Windows CSD build number  : %g_strWindowsCSDBuildNumber%
echo.


REM ----------------------------------------
REM
REM Get Windows version
REM
REM ----------------------------------------
"!g_strCommandWinVersion4FullPath!" -type LEGACY
set g_uWinVersion=%ERRORLEVEL%

IF %g_uWinVersion%==150 GOTO WinVersionWindowsHomeServer
IF %g_uWinVersion%==107 GOTO WinVersionWindowsServer2012R2
IF %g_uWinVersion%==106 GOTO WinVersionWindowsServer2012
IF %g_uWinVersion%==105 GOTO WinVersionWindowsServer2008R2
IF %g_uWinVersion%==104 GOTO WinVersionWindowsServer2008
IF %g_uWinVersion%==103 GOTO WinVersionWindowsServer2003R2
IF %g_uWinVersion%==102 GOTO WinVersionWindowsServer2003
IF %g_uWinVersion%==101 GOTO WinVersionWindowsServer2000
IF %g_uWinVersion%==100 GOTO WinVersionWindowsServerNT
IF %g_uWinVersion%==28 GOTO WinVersionWindows10
IF %g_uWinVersion%==27 GOTO WinVersionWindows8Dot1
IF %g_uWinVersion%==26 GOTO WinVersionWindows8
IF %g_uWinVersion%==25 GOTO WinVersionWindows7
IF %g_uWinVersion%==24 GOTO WinVersionWindowsVista
IF %g_uWinVersion%==23 GOTO WinVersionWindowsXP
IF %g_uWinVersion%==22 GOTO WinVersionWindows2000
IF %g_uWinVersion%==21 GOTO WinVersionWindowsNT40
IF %g_uWinVersion%==20 GOTO WinVersionWindowsNT351
IF %g_uWinVersion%==13 GOTO WinVersionWindowsMe
IF %g_uWinVersion%==12 GOTO WinVersionWindows98OSR2
IF %g_uWinVersion%==11 GOTO WinVersionWindows98
IF %g_uWinVersion%==10 GOTO WinVersionWindows95
GOTO EndOfMenuWinVersion

:WinVersionWindowsHomeServer
set g_strWinVersion=Windows Home Server
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2012R2
set g_strWinVersion=Windows Server 2012 R2
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2012
set g_strWinVersion=Windows Server 2012
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2008R2
set g_strWinVersion=Windows Server 2008 R2
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2008
set g_strWinVersion=Windows Server 2008
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2003R2
set g_strWinVersion=Windows Server 2003 R2
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2003
set g_strWinVersion=Windows Server 2003
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServer2000
set g_strWinVersion=Windows Server 2000
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindowsServerNT
set g_strWinVersion=Windows Server NT
set g_bIsServer=1
GOTO EndOfMenuWinVersion

:WinVersionWindows10
set g_strWinVersion=Windows 10'
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows8Dot1
set g_strWinVersion=Windows 8.1 'Blue'
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows8
set g_strWinVersion=Windows 8
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows7
set g_strWinVersion=Windows 7
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindowsVista
set g_strWinVersion=Windows Vista
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindowsXP
set g_strWinVersion=Windows XP
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows2000
set g_strWinVersion=Windows 2000
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindowsNT40
set g_strWinVersion=Windows NT 4.0
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindowsNT351
set g_strWinVersion=Windows NT 3.51
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindowsMe
set g_strWinVersion=WindowsMe
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows98OSR2
set g_strWinVersion=Windows98OSR2
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows98
set g_strWinVersion=Windows98
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:WinVersionWindows95
set g_strWinVersion=Windows95
set g_bIsServer=0
GOTO EndOfMenuWinVersion

:EndOfMenuWinVersion

echo.
echo Windows version number    : %g_uWinVersion%
echo Windows version           : %g_strWinVersion%
echo Is server                 : %g_bIsServer%

echo Use CheckRange to verify Server/Workstation :
"!g_strCommandCheckRange4FullPath!" -n 0 99 %g_uWinVersion% -q
IF %ERRORLEVEL%==0 (
    echo Outside of range - It's a Windows Server version
)
IF %ERRORLEVEL%==1 (
    echo Inside range - It's a Windows Workstation version
)
echo.

echo Server check alternative :
"!g_strCommandWinVersion4FullPath!" -type ISSERVER -q
set g_uWinVersion=%ERRORLEVEL%
IF %g_uWinVersion%==1 (
    echo It's a Windows Server version
) else (
    echo It's a Windows Workstation version
)
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------