
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * FTP 4                                          *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        FTP transfert.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_strFtpServer                  String     Static         FTP server (IP or Netbios name)
rem         g_strFtpServerPort              String     Static         FTP port
rem         g_strFtpLogin                   String     Static         FTP user login
rem         g_strFtpPassword                String     Static         FTP user password
rem         g_strFtpRemoteFolder            String     Static         FTP remote folder
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log
set g_strTempFolder=!g_strBatchPath!\..\temp

set g_strCommandFtp4FullPath=!g_strCmdLineToolsFolder!\Ftp4.exe

rem Display current directory
echo - Batch directory : 
echo !g_strBatchPath!
echo.
rem Display current directory
echo - Current directory : 
echo !g_strCurrentDirectory!
echo.
rem Display CmdLineTools directory
echo - CmdLineTools directory : 
echo !g_strCmdLineToolsFolder!
echo.

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

rem FTP pre-configuration
set g_strFtpServer=192.168.1.200
set g_strFtpServerPort=21
set g_strFtpLogin=MyAccount
set g_strFtpPassword=Password1234
set g_strFtpRemoteFolder=Public
set g_strSourceFilename=Src1.txt
rem Don't backslash at the end of the path
set g_strFtpLocalFolder=!g_strBatchPath!\..\datas
set g_strFtpTempFolder=!g_strBatchPath!\..\temp

:LabelFtpServer
ECHO.
set /P g_strFtpServer=Enter FTP server IP or name: 
IF '%g_strFtpServer%'=='' (
    ECHO Empty input, try again
    goto:LabelFtpServer
)

:LabelFtpServerPort
ECHO.
set /P g_strFtpServerPort=Enter FTP server port : 
IF '%g_strFtpServerPort%'=='' (
    ECHO Empty input, try again
    goto:LabelFtpServerPort
)

:LabelLogin
ECHO.
set /P g_strFtpLogin=Enter FTP user account : 
IF '%g_strFtpLogin%'=='' (
    ECHO Empty input, try again
    goto:LabelLogin
)

:LabelPassword
ECHO.
set /P g_strFtpPassword=Enter FTP user password : 
IF '%g_strFtpPassword%'=='' (
    ECHO Empty input, try again
    goto:LabelPassword
)

:LabelRemoteFolder
ECHO.
set /P g_strFtpRemoteFolder=Enter FTP remote folder : 
IF '%g_strFtpRemoteFolder%'=='' (
    ECHO Empty input, try again
    goto:LabelRemoteFolder
)

echo.
echo Cleanup previous files :
echo ------------------------
del /Q "!g_strFtpTempFolder!\!g_strSourceFilename!"

echo.
echo FTP Transfert sample (PUSH) :
echo -----------------------------
"!g_strCommandFtp4FullPath!" -url "ftp://%g_strFtpServer%" -port %g_strFtpServerPort% -active -login %g_strFtpLogin% -password %g_strFtpPassword% -local "!g_strFtpLocalFolder!" -remote "%g_strFtpRemoteFolder%" -file "!g_strSourceFilename!" -mode PUSH 
if %ERRORLEVEL%==-1 (
    echo Help displayed - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else if %ERRORLEVEL%==1 (
    echo All is OK.
) else if %ERRORLEVEL%==0 (
    echo Value not found - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else (
    echo ERROR - Unknown value - WE CAN'T REACH THIS CASE IN THIS SAMPLE
)
echo.

echo.
echo FTP Transfert sample (GET) :
echo ----------------------------
rem Change local folder to TEMP
rem Don't backslash at the end of the path
"!g_strCommandFtp4FullPath!" -url "ftp://%g_strFtpServer%" -port %g_strFtpServerPort% -active -login %g_strFtpLogin% -password %g_strFtpPassword% -local "!g_strFtpTempFolder!" -remote "%g_strFtpRemoteFolder%" -file "!g_strSourceFilename!" -mode GET 
if %ERRORLEVEL%==-1 (
    echo Help displayed - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else if %ERRORLEVEL%==1 (
    echo All is OK.
) else if %ERRORLEVEL%==0 (
    echo Value not found - WE CAN'T REACH THIS CASE IN THIS SAMPLE
) else (
    echo ERROR - Unknown value - WE CAN'T REACH THIS CASE IN THIS SAMPLE
)
echo.
echo.
echo Launch notepad to read orignal file
notepad "!g_strFtpLocalFolder!\!g_strSourceFilename!"
echo Launch notepad to read downloaded file
notepad "!g_strFtpTempFolder!\!g_strSourceFilename!"
echo.

rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------