
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * AppVersion4                                    *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Check application version.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_strSourceFullFilename         String     Temp           Source filename to use in this tutorial.
rem         g_strArguments                  String     Temp           Argument passed to AppVersion4 application.
rem 
rem         g_strFileVersion                String     Output         File version.
rem         g_strProductVersion             String     Output         Product version.
rem         g_strProductVersionMAJ          String     Output         Product version (major).
rem         g_strProductVersionMIN          String     Output         Product version (minor).
rem         g_strProductVersionBD           String     Output         Product version (build).
rem         g_strMD5                        String     Output         MD5 hash code.
rem         g_strSHA1                       String     Output         SHA-1 hash code.
rem         g_strCert                       String     Output         Digital certificate.
rem 
rem: Notes :
rem         How to get hash code of application    : Hashtab - http://implbits.com/HashTab/HashTabWindows.aspx
rem         Documentation for string manipulations : http://www.dostips.com/DtTipsStringManipulation.php
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log

set g_strCommandAppVersion4FullPath=!g_strCmdLineToolsFolder!\AppVersion4.exe

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

rem set g_strSourceFullFilename=%WINDIR%\notepad.exe
set g_strSourceFullFilename=!g_strBatchPath!\..\datas\notepad.exe

rem Get new result
rem --------------
echo Get file version
set g_strFileVersion=cleared variable
set g_strArguments=-fv -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strFileVersion= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Get product version (pv)
set g_strProductVersion=cleared variable
set g_strArguments=-pv -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strProductVersion= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Get product version (pvmaj)
set g_strProductVersionMAJ=cleared variable
set g_strArguments=-pvmaj -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strProductVersionMAJ= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Get product version (pvmin)
set g_strProductVersionMIN=cleared variable
set g_strArguments=-pvmin -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strProductVersionMIN= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Get product version (build)
set g_strProductVersionBD=cleared variable
set g_strArguments=-pvbd -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strProductVersionBD= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Compute MD5
set g_strMD5=cleared variable
set g_strArguments=-md5 -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strMD5= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Compute SHA-1
set g_strSHA1=cleared variable
set g_strArguments=-sha1 -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strSHA1= < "%g_strInternalOutputFullFilename%"

rem Get new result
rem --------------
echo Get certificate
set g_strCert=cleared variable
set g_strArguments=-cert -f 
"!g_strCommandAppVersion4FullPath!" %g_strArguments% "%g_strSourceFullFilename%" > "%g_strInternalOutputFullFilename%"
set /p g_strCert= < "%g_strInternalOutputFullFilename%"


rem Display result
rem --------------
echo.
echo.
echo ---------------------------------------------------
echo Filename        : %g_strSourceFullFilename%
echo File version    : %g_strFileVersion%
echo Product version : %g_strProductVersion% (%g_strProductVersionMAJ%.%g_strProductVersionMIN% Build %g_strProductVersionBD%)
echo Hash MD5        : %g_strMD5%
echo Hash SHA1       : %g_strSHA1%
echo Certificate     : %g_strCert%
echo ---------------------------------------------------
echo.

rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------