
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * UpdateApp 4                                    *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Update applications.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_b64BitsOS                     Boolean    Output         0=32 bits OS. 1=64 bits OS.
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log
set g_strDownloadFolder=%TEMP%

set g_strCommandIs64Bits4FullPath=!g_strCmdLineToolsFolder!\Is64Bits4.exe
set g_strCommandUpdateApp4FullPath=!g_strCmdLineToolsFolder!\UpdateApp4.exe

CALL :FunctionIs64Bits

echo WARNING : This sample will terminate all web browsers. Save all before continue.
Pause
CALL :FunctionKillWebBrowsers

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

echo.
echo Update Nolme Informatique CmdLineTools
"!g_strCommandUpdateApp4FullPath!" -guid "{78F3A65F-31D3-4124-86C6-7E8A4FCC23B2}_is1" -x64 -last "4.0.0.0" -url "http://www.nolme.com/datas/cmdlinetools/" -d "!g_strDownloadFolder!" -f "CmdLineTools4_setup.exe" -md5 4C78AD7CCA6DEBA44B067BE12C3F649C -args "/VERYSILENT"


echo.
echo Update 7-Zip x86 if present
"!g_strCommandUpdateApp4FullPath!" -name "7-Zip" -x86 -last "15.10 beta" -url "http://7-zip.org/a" -f "7z1510.exe" -d "!g_strDownloadFolder!" -md5 D808CCD899F1F1B477CB3D1D8BC4AAE2 -args "/S"

if %g_b64BitsOS%==1 (
    echo.
    echo Update 7-Zip x64 if present
    "!g_strCommandUpdateApp4FullPath!" -name "7-Zip" -x64 -last "15.10 beta" -url "http://7-zip.org/a" -f "7z1510-x64.exe" -d "!g_strDownloadFolder!" -md5 BDF19C9CE0CAB3100B84FFB2EB3216A2 -args "/S"
)

echo.
echo Update Oracle Java x86
"!g_strCommandUpdateApp4FullPath!" -name "Java" "{26A24AE4-039D-4CA4-87B4-2F83218065F0}" -x86 -last "8.0.650.17" -url "http://javadl.sun.com/webapps/download/AutoDL?BundleId=111687" -d "!g_strDownloadFolder!" -df "jre-8u65-windows-i586.exe" -u -md5 17225BAF574EDA49F69D229EF9E6E0A5 -args "/s"

if !g_b64BitsOS!==1 (
    echo.
    echo Update Oracle Java x64
    "!g_strCommandUpdateApp4FullPath!" -name "Java" "{26A24AE4-039D-4CA4-87B4-2F86418065F0}" -x64 -last "8.0.650.17" -url "http://javadl.sun.com/webapps/download/AutoDL?BundleId=111689" -d "!g_strDownloadFolder!" -df "jre-8u65-windows-x64.exe" -u -md5 A7FB10369E31AB07596505162699B685 -args "/s"
)

echo.
echo Update Adobe Reader 11 if present (use latest full setup)
"!g_strCommandUpdateApp4FullPath!" -guid "{AC76BA86-7AD7-1036-7B44-AB0000000001}" -x86 -last "11.0.10" -url "ftp://ftp.adobe.com/pub/adobe/reader/win/11.x/11.0.10/fr_FR/" -f "AdbeRdr11010_fr_FR.exe" -d "!g_strDownloadFolder!" -md5 785EDE9E0456F17BC0BB16299880E18D -args "/sPB"

echo.
echo Update Adobe Reader using patch)
echo compare for patch
"!g_strCommandUpdateApp4FullPath!" -name "AdobeReader11" -x86 -last "11.0.13" -url "ftp://ftp.adobe.com/pub/adobe/reader/win/11.x/11.0.13/misc/" -f "AdbeRdrUpd11012.msp" -d "!g_strDownloadFolder!" -md5 8DFE082E68A456A8088776D3AA204ED9 -args "/qb"


echo.
echo Update Adobe Reader DC 15 if present (use latest full setup)
"!g_strCommandUpdateApp4FullPath!" -guid "{AC76BA86-7AD7-1036-7B44-AC0F074E4100}" -x86 -last "15.009.20069" -url "ftp://ftp.adobe.com/pub/adobe/reader/win/AcrobatDC/1500920069/" -f "AcroRdrDC1500920069_fr_FR.exe" -d "!g_strDownloadFolder!" -md5 C4E13C5CE784702C2D6818115627F06B -args "/sPB"

echo.
echo Update Adobe Reader DC 15 using patch)
echo compare for patch
"!g_strCommandUpdateApp4FullPath!" -name "AdobeReaderDC15" -x86 -last "15.009.20077" -url "ftp://ftp.adobe.com/pub/adobe/reader/win/AcrobatDC/1500920077/" -f "AcroRdrDCUpd1500920077.msp" -d "!g_strDownloadFolder!" -md5 775A31DA0A4D38B773E97B1F54F138A4 -args "/qb"




rem For the space before '-silent' or '-install' switch is mandatory because of Nolme Kernel managing arguments.
echo.
echo Update Adobe AIR if present
"!g_strCommandUpdateApp4FullPath!" -guid "Adobe AIR" -x86 -last "19.0.0.213" -url "http://airdownload.adobe.com/air/win/download/19.0" -f "AdobeAIRInstaller.exe" -d "!g_strDownloadFolder!" -md5 F3A743A4B57F5B31CB4C6660F79BB027 -args " -silent"

echo.
echo Update Adobe FlashPlayer ActiveX if present [auto skip for Windows 8.x and newer because it's embedded]
"!g_strCommandUpdateApp4FullPath!" -guid "Adobe Flash Player ActiveX" -x86 -last "19.0.0.226" -url "http://download.macromedia.com/get/flashplayer/current/licensing/win" -f "install_flash_player_19_active_x.exe" -d "!g_strDownloadFolder!" -md5 2DF5A2C99455431FC5E84CB0C2FCCA3C -args " -install" 

echo.
echo Update Adobe FlashPlayer Plugin
"!g_strCommandUpdateApp4FullPath!" -guid "Adobe Flash Player NPAPI" -x86 -last "19.0.0.226" -url "http://download.macromedia.com/get/flashplayer/current/licensing/win" -f "install_flash_player_19_plugin.exe" -d "!g_strDownloadFolder!" -md5 DDD05555A7B3E2F9D3204FDE57DBAA43 -args " -install" 

echo.
echo Update CD Burner XP if present
"!g_strCommandUpdateApp4FullPath!" -guid "{7E265513-8CDA-4631-B696-F40D983F3B07}_is1" -x86 -last "4.5.6.5844" -url "http://cdburnerxp.se" -f "downloadsetup.exe" -d "!g_strDownloadFolder!" -md5 AC777821BCDE0A95D6DD09CA8C49E46D -args "/VERYSILENT"

echo.
echo Update Easeware DriverEasy if present
"!g_strCommandUpdateApp4FullPath!" -guid "DriverEasy_is1" -x64 -last "4.9.6.0" -url "http://www.drivereasy.com" -f "DriverEasy_Setup.exe" -d "!g_strDownloadFolder!" -md5 FFC78C913343787A913101782A1AF185 -args "/SILENT"
TASKKILL /F /im DriverEasy.exe
SchTasks /Delete /F /TN "DriverEasy Scheduled Scan"

echo.
echo Update Microsoft Skype if present
"!g_strCommandUpdateApp4FullPath!" -guid "{6A0549A9-1B96-498C-ACBC-3943001FEB19}" -x86 -last "7.13.0.101" -url "http://www.skype.com/go/getskype-full" -df "SkypeSetupFull.exe" -d "!g_strDownloadFolder!" -md5 B112788E0DEE128A188ECBEA9CE8A67F -args "/VERYSILENT /SP- /NOCANCEL /NORESTART /SUPPRESSMSGBOXES /NOLAUNCH"

echo.
echo Update Mozilla Firefox if present
"!g_strCommandUpdateApp4FullPath!" -name "Firefox" -x86 -last  "42.0" -url "https://download-installer.cdn.mozilla.net/pub/firefox/releases/42.0/win32/fr/" -f "Firefox Setup 42.0.exe" -d "!g_strDownloadFolder!" -md5 3FEF8648B2D8323B4D27D214E02511B8 -args " -ms"

echo.
echo Update Mozilla Thunderbird if present
"!g_strCommandUpdateApp4FullPath!" -name "Thunderbird" -x86 -last  "38.3.0" -url "http://download-installer.cdn.mozilla.net/pub/thunderbird/releases/38.3.0/win32/fr/" -f "Thunderbird Setup 38.3.0.exe" -d "!g_strDownloadFolder!" -md5 915FF3984353B5041DAF76D795763FB0 -args " -ms"

echo Update Notepad++ if present
"!g_strCommandUpdateApp4FullPath!" -guid "Notepad++" -x86 -last "6.8.6" -url "https://notepad-plus-plus.org/repository/6.x/6.8.6" -f "npp.6.8.6.Installer.exe" -d "!g_strDownloadFolder!" -md5 E3C2C3A7E9AE491204CE3FAC3D8B4A38 -args "/S"

echo.
echo Update PeaZIP x86 if present
"!g_strCommandUpdateApp4FullPath!" -guid "{5A2BC38A-406C-4A5B-BF45-6991F9A05325}_is1" -x86 -last "5.8.1" -url "http://optimate.dl.sourceforge.net/project/peazip/5.8.1" -f "peazip-5.8.1.WINDOWS.exe" -d "!g_strDownloadFolder!" -md5 0360D5636E49201503229658AFE89B51 -args "/VERYSILENT" -process "peazip.exe"

if %g_b64BitsOS%==1 (
    echo.
    echo Update PeaZIP x64 if present
    "!g_strCommandUpdateApp4FullPath!" -guid "{5A2BC38A-406C-4A5B-BF45-6991F9A05325}_is1" -x64 -last "5.8.1" -url "http://optimate.dl.sourceforge.net/project/peazip/5.8.1" -f "peazip-5.8.1.WIN64.exe" -d "!g_strDownloadFolder!" -md5 2B001940C4E8409E8CCA598D56C3A0FD -args "/VERYSILENT" -process "peazip.exe"
)

echo.
echo Update TreeSize Free if present
"!g_strCommandUpdateApp4FullPath!" -guid "TreeSize Free_is1" -x86 -last "3.3.2" -url "http://www.jam-software.de/treesize_free/" -f "TreeSizeFreeSetup.exe" -d "!g_strDownloadFolder!" -md5 FA6BD66592E84843A4E1E8688DF2E274 -args "/VERYSILENT" 

echo.
echo Update VideoLAN VLC if present
"!g_strCommandUpdateApp4FullPath!" -guid "VLC media player" -x86 -last "2.2.1" -url "ftp://ftp.free.org/mirrors/videolan/vlc/2.2.1/win32/" -f "vlc-2.2.1-win32.exe" -d "!g_strDownloadFolder!" -md5 B8C997E772BE343E1664FEE14C1FB9B7 -args " /S" 



echo.
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>

rem <LIBRARY>
rem ************************************************************************************************************************
rem 
rem FunctionIs64Bits ()
rem 
rem ************************************************************************************************************************
rem 
rem: Description :
rem         Initialize variable for 32/64 bits Windows version.
rem 
rem: Informations :
rem         Version       : 1.0
rem         Last modified : 2015-10-07
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strCommandIs64Bits4FullPath   String     Input          Full filename for application Is64Bits4.exe.
rem         g_b64BitsOS                     Boolean    Output         0=32 bits or error, 1=64 bits Windows version.
rem 
rem ************************************************************************************************************************
:FunctionIs64Bits
rem call command
"!g_strCommandIs64Bits4FullPath!" -q

rem check command result
if %ERRORLEVEL%==1 (
    set g_b64BitsOS=1
) else if %ERRORLEVEL%==0 (
    set g_b64BitsOS=0
) else (
    set g_b64BitsOS=0
    ECHO FunctionIs64Bits - Error getting 32/64 bits mode
)

rem display result
if %g_b64BitsOS%==1 (
    ECHO FunctionIs64Bits - This is a 64 bits Windows version
) else (
    ECHO FunctionIs64Bits - This is a 32 bits Windows version
)

:FunctionIs64Bits_End
GOTO:EOF

rem ************************************************************************************************************************
rem 
rem FunctionKillWebBrowsers ()
rem 
rem ************************************************************************************************************************
rem 
rem: Description :
rem     Kill all web browser which can be used for third party tools (flash, shockwave) and for web browser update.
rem 
rem: Informations :
rem     Version       : 1
rem     Last modified : 2015-10-07
rem 
rem ************************************************************************************************************************
:FunctionKillWebBrowsers

rem Kill various browsers
CALL :FunctionKillProcess "firefox.exe"
CALL :FunctionKillProcess "iexplore.exe"
CALL :FunctionKillProcess "opera.exe"
CALL :FunctionKillProcess "safari.exe"
CALL :FunctionKillProcess "chrome.exe"

:FunctionKillWebBrowsers_End
GOTO:EOF


rem ************************************************************************************************************************
rem 
rem FunctionKillProcess ()
rem 
rem ************************************************************************************************************************
rem 
rem: Description :
rem     Kill an application using its process name
rem 
rem: Informations :
rem     Version       : 1
rem     Last modified : 2015-10-07
rem 
rem: Variables :
rem     Name                              Type           Visibility     Values / Comment
rem     ----------------------------------------------------------------------------------------------------------------
rem     %1                                String         Input          Process name to kill(with file extension) AND double quotes "
rem
rem     g_strAppResult                    String         Output         Function result = 'not initialized'
rem     g_bError                          Boolean        Output         1=error, 0=OK
rem
rem     strAppExecutableWithQuotes        String         Internal       Internal variable
rem     strAppExecutable                  String         Internal       Internal variable
rem 
rem: Notes :
rem     We're using the TASKKILL tool which is provided with Windows XP Pro and after.
rem     See : http://technet.microsoft.com/en-us/library/bb491009.aspx
rem
rem ************************************************************************************************************************
:FunctionKillProcess
rem Reset variables
set g_bError=0
set g_strAppResult=not initialized

rem Init parameters
set strAppExecutableWithQuotes=%1
rem set strAppExecutable=!strAppExecutableWithQuotes:~1,-1!
set strAppExecutable=!strAppExecutableWithQuotes:"=!

rem Check empty parameter
IF "!strAppExecutable!"=="" (
	CALL :FunctionDebugEcho 1 "Error - Application executable name empty."
	set g_bError=1
	GOTO:FunctionKillProcess_End
)

rem Kill all instances
TASKKILL /F /im "!strAppExecutable!"

:FunctionKillProcess_End
GOTO:EOF

rem </LIBRARY>

rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------