
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * Kaspersky GetSystemInfo + logs                 *
echo *                                                *
echo **************************************************
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_strArchiveFullPath            String     Static         Full filename for archive file containing logs.
rem 
rem: Notes :
rem         Kaspersky GetSystemInfo can be downloaded from : http://www.getsysteminfo.com/
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log

set g_strCommandMail4FullPath=!g_strCmdLineToolsFolder!\Mail4.exe
set g_strTool7ZipPath=!g_strCmdLineToolsFolder!\7z\7za.exe
set g_strToolGsi=!g_strBatchPath!\GetSystemInfo.exe

rem Report informations
set g_strReportFolder=%TEMP%\Report_GsiReport
set g_strReportArchive=GsiReport_%COMPUTERNAME%-%USERNAME%.7z
set g_strReportArchiveFullPath=%TEMP%\!g_strReportArchive!

rem Events
set g_strApplicationLog=%SystemRoot%\System32\Winevt\Logs\Application.evtx
set g_strSecurityLog=%SystemRoot%\System32\Winevt\Logs\Security.evtx
set g_strSetupLog=%SystemRoot%\System32\Winevt\Logs\Setup.evtx
set g_strSystemLog=%SystemRoot%\System32\Winevt\Logs\System.evtx
set g_strKasperskyLog=%SystemRoot%\System32\Winevt\Logs\Kaspersky Event Log.evtx

rem [EDIT THIS PART] E-mail informations -----------------------------------
set g_strSenderName=GsiReport
set g_strSenderEmail=support@nolme.com
set g_strDestinationEmail=support@nolme.com
set g_strSmtpServer=smtp.server.net
set g_strSmtpName=MyEmailAccountForAuthentification
set g_strSmtpPwd=MyEmailAccountPassword
set g_strEmailSubject=Gsi report (%COMPUTERNAME%-%USERNAME%)
set g_strEmailBody=This is the ^<b^>GsiReport^</b^> report.^<br/^>
rem [END EDIT] -------------------------------------------------------------

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.

rem ----------------------------------
echo Is there already a previous report to delete ?
if exist "!g_strReportArchiveFullPath!" goto yes1
goto no1
:yes1
	echo YES. Remove previous folder
	del /Q /F "!g_strReportArchiveFullPath!"
 	goto NextStep1
:no1
	rem Previous report don't exist, nothing to do
	echo No. There isn't a previous report to remove
	goto NextStep1
:NextStep1
echo Done.
echo.

rem ----------------------------------
echo Is there already a previous folder to delete ?
if exist "!g_strReportFolder!" goto yes2
goto no2
:yes2
	echo YES. Remove previous folder
	rmdir /S /Q "!g_strReportFolder!"
 	goto NextStep2
:no2
	rem Directory don't exist, nothing to do
	echo No. There isn't a previous folder to remove
	goto NextStep2
:NextStep2
echo Done.
echo.

rem ----------------------------------
echo Make backup directory (destroy any previous version)
md "!g_strReportFolder!"
echo Done.
echo.

rem ----------------------------------
echo Backup event logs
echo Application [!g_strApplicationLog!]
copy "!g_strApplicationLog!" "!g_strReportFolder!"

echo Security [!g_strSecurityLog!]
copy "!g_strSecurityLog!" "!g_strReportFolder!"

echo Setup [!g_strSetupLog!]
copy "!g_strSetupLog!" "!g_strReportFolder!"

echo System [!g_strSystemLog!]
copy "!g_strSystemLog!" "!g_strReportFolder!"

echo Kaspersky [!g_strKasperskyLog!]
copy "!g_strKasperskyLog!" "!g_strReportFolder!"
echo.

rem ----------------------------------
echo Run GsiReport
rem /l=log detail [1=mini, 2=recommended, 3=maximum]
"!g_strToolGsi!" /EULA=0 /qn 
echo Done.
echo.

rem Pack all datas
echo Pack datas
IF NOT EXIST !g_strTool7ZipPath! (
    Echo ZIP DN't EXIST: '!g_strTool7ZipPath!'
    Pause
)
"!g_strTool7ZipPath!" a -t7z -r "!g_strReportArchiveFullPath!"   "!g_strReportFolder!\*"
echo Done.
echo.

rem --------------------------------
rem Send e-mail "!g_strReportArchiveFullPath!".
ECHO Send email...
"!g_strCommandMail4FullPath!" -fn "%g_strSenderName%" -fm "%g_strSenderEmail%" -tm "%g_strDestinationEmail%" -s "%g_strEmailSubject%" -b "%g_strEmailBody%" -html -smtp "%g_strSmtpServer%" -smtpName "%g_strSmtpName%" -smtpPassword "%g_strSmtpPassword%" -add "!g_strReportArchiveFullPath!"
if %ERRORLEVEL%==-1 (
    echo Help displayed.
) else if %ERRORLEVEL%==1 (
    echo All is OK.
) else if %ERRORLEVEL%==0 (
    echo ERROR - Value not found.
) else (
    echo ERROR - Unknown value.
)


echo.
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------